#!/usr/bin/env python
# -*- coding: utf-8 -*-

import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
# from scipy import stats
# import statsmodels.api as sm
# from numpy.random import randn
import matplotlib as mpl
# import seaborn as sns

# sns.set_color_palette("deep", desat=.6)
mpl.rc("figure", figsize=(8, 4))

def Compavg():
	data=Total()
	markMax=[]
	markAvg=[]
	N = 5
	ind = np.arange(N)    
	width = 0.35 
	fig = plt.figure()
	ax = fig.add_subplot(111)      
	markMax.extend((data["Total"].max(),data["Total.1"].max(),data["Total.2"].max(),data["Total.3"].max(),data["Total.4"].max()))
	markAvg.extend((data["Total"].mean(),data["Total.1"].mean(),data["Total.2"].mean(),data["Total.3"].mean(),data["Total.4"].mean()))
	rects1 = ax.bar(ind, markMax, width, color='black')
	rects2 = ax.bar(ind+width, markAvg, width, color='green')
	ax.set_xlim(-width,len(ind)+width)
	ax.set_ylim(0,120)
	ax.set_ylabel('Marks')
	ax.set_title('Max, Mean and Your Marks')
	xTickMarks = ['Subject'+str(i) for i in range(1,6)]
	ax.set_xticks(ind+width)
	xtickNames = ax.set_xticklabels(xTickMarks)
	plt.setp(xtickNames, rotation=10, fontsize=10)
	ax.legend( (rects1[0], rects2[0]), ('Max', 'Mean') )
	plt.show()
	
def compSub():
	# max_data = np.r_[data["Total"]].max()
	# bins = np.linspace(0, max_data, max_data + 1)
	data=Total()
	plt.hist(data['Total'],linewidth=0, alpha=.7)
	plt.hist(data['Total.1'],linewidth=0,alpha=.7)
	plt.hist(data['Total.2'],linewidth=0,alpha=.7)
	plt.hist(data['Total.3'],linewidth=0,alpha=.7)
	plt.hist(data['Total.4'],linewidth=0,alpha=.7)
	plt.title("Total marks Histogram")
	plt.xlabel("Value")
	plt.ylabel("Frequency")
	plt.show()

def Total():
	data=pd.read_csv("output10cs.csv")
	df3=data[['Total','Total.1','Total.2','Total.3','Total.4','Total.5','Total.6','Total.7']]
	data["Main Total"]=df3.sum(axis=1)
	data = data.dropna()
	data.reset_index(drop=True)
	return data

#compSub()
# Compavg()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

usn=""
usnl=[]
from bs4 import BeautifulSoup 
import select
import asys
import glob
import os
import sys
import shutil
from select import select
timeout=10

def inputIndex():
	import codecs
	x=0
	fl = codecs.open('output'+sys.argv[1]+sys.argv[2]+'.csv', 'wb',encoding="Utf-8")
	fl.write("usn,")
	while x<8:
		fl.write("External,Internal,Total,")
		x+=1
	fl.write("Main Total\n")
	fl.close()

def getval():
	import codecs
	record=[]
	x=0
	while x<len(usnl):
		page_html=open("results/"+usnl[x]+".html", 'rb')
		soup=BeautifulSoup(page_html)
		soup.prettify()
		fl = codecs.open('output'+sys.argv[1]+sys.argv[2]+'.csv', 'ab',encoding="Utf-8")
		record=[texts.text for texts in soup.findAll('td',{"align":"center"})]
		"""for y in soup.findAll("td"):
			if y.parent.name=="tr":
				lol.append(y.text)
		if lol[-10] == "A" or lol[-10]=="P" or lol[-10]=="F":
			lol[-10],lol[-1]=lol[-1],lol[-10]"""
		del record[0:4]
		for y in record:
			if "P" in y: record.remove("P")
			elif "F" in y: record.remove("F")
			elif "A" in y: record.remove("A")
				
		if len(record)>24:
			del record[24:]
		if "Total" in record: del record[:]	
		if record:
			fl.write("\n"+usnl[x]+",")
			for y in record:
				fl.write(y)
				fl.write(",")
				# fl.write(lol[-10])
			fl.close()
		x+=1
	
def parsehtml(response,x):
	#files=glob.glob("results/*.*")
	#files.sort()
	#x=0
	#print files
	#for f in files:
	#page_html=open(f)
	soup=BeautifulSoup(response.read())
	all_tds = [td for td in soup.findAll("td", width="513")]
	fl = open("results/"+usnl[x]+".html", 'wb')
	lol=all_tds[0]
	record = '%s' % (lol)
	if record:
		fl.write(record)
	fl.close()
	#x=x+1
		
def ret():
	import shutil
	import mechanize
	year=sys.argv[1]
	branches=sys.argv[2]
	x=0
	for rno in range(1,3):
		usn="4pa"+year+branches+"%03d"%rno
		print usn
		br = mechanize.Browser()
		br.set_handle_robots(False)
		br.open("http://results.vtu.ac.in/")
		#fl=open("results/"+usn+".html","wb")
		br.select_form(nr=0)
		br['rid']=usn
		response=br.submit()
		usnl.append(usn)
		parsehtml(response,x)
		x=x+1		
		#shutil.copyfileobj(br.submit(),fl)		
		#fl.close()
		
			

def main():
	inputIndex()
	if not os.path.exists("results"):
		os.makedirs("results")
	ret()
	#parsehtml()
	getval()
	while True:		
		print("""1.Compute average
2.Compare with max and average
3.Quit""")
		rlist, _, _ = select([sys.stdin], [], [], timeout)		
		if(rlist):
			sel=sys.stdin.readline()
		else:
			print "Time out exiting"			
			break		
		#sel=raw_input("Select an Analysis\n")
		if sel=="1":
			asys.Compavg()
		elif sel=='2':
			asys.compSub()
		elif sel=='3':
			print("Exiting")
			break
	shutil.rmtree('results')
	return 0


if __name__ == '__main__':
	inputIndex()
	main()
	#asys.Compavg()
	#asys.compSub()

# TODO:Names of those whose result has not come out



from ez_setup import use_setuptools
use_setuptools()
from setuptools import setup, find_packages
from setuptools.command.test import test as TestCommand
import vturra
import sys
import codecs
try:
	codecs.lookup('mbcs')
except LookupError:
	ascii = codecs.lookup('ascii')
	func = lambda name, enc=ascii: {True: enc}.get(name=='mbcs')
	codecs.register(func) 

class PyTest(TestCommand):
    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        import pytest
        errcode = pytest.main(self.test_args)
        sys.exit(errcode)

setup(name="vturra",
    version=vturra.__version__,
    license='MIT Software License',
    tests_require=['pytest'],
    install_requires=[
                      'mechanize',
                      'patsy',
                      'BeautifulSoup4',
                      'numpy',
                      'scipy',
                      'matplotlib>=1.2.1',
                      'pandas<0.13'
                     ],
    cmdclass={'test': PyTest},
    description="Downloads results from VTU website and analyzes the result",
    long_description=open('README.rst').read(),
    author="Muhammed Thaha",
    author_email='mthaha1989@gmail.com',
    download_url='https://github.com/stormvirux/vturra',
    packages=find_packages(exclude='tests'),
    package_data={'vturra': ['data/*.xml']},
    include_package_data=True,
    platforms='any',
    test_suite='vturra.test.test_vturra',
    classifiers = [
        'Programming Language :: Python',
        'Development Status :: 5 - Production/Stable',
        'Natural Language :: English',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Topic :: Scientific/Engineering :: Information Analysis'
        ],
    extras_require={
        'testing': ['pytest'],
    },
    entry_points={
        "console_scripts": [
            "vturra=vturra.rra:main"
            #"pip%s=pip:main" % sys.version[:1],
            #"pip%s=pip:main" % sys.version[:3],
        ],
    }
)

